beamtools.get_beam_spanner_attached_to_component
================================================

.. autofunction:: abjad.tools.beamtools.get_beam_spanner_attached_to_component.get_beam_spanner_attached_to_component
   :noindex:
